<?php

namespace OxidSolutionCatalysts\PayPalApi\Model\Disputes;

use JsonSerializable;
use OxidSolutionCatalysts\PayPalApi\Model\BaseModel;
use Webmozart\Assert\Assert;

/**
 * A customer request to deny the offer made by the merchant.
 *
 * generated from: request-deny_offer.json
 */
class RequestDenyOffer implements JsonSerializable
{
    use BaseModel;

    /**
     * The customer notes about the denial of offer. PayPal can but the merchant cannot view these notes.
     *
     * @var string
     * minLength: 1
     * maxLength: 2000
     */
    public $note;

    public function validate($from = null)
    {
        $within = isset($from) ? "within $from" : "";
        Assert::notNull($this->note, "note in RequestDenyOffer must not be NULL $within");
        Assert::minLength(
            $this->note,
            1,
            "note in RequestDenyOffer must have minlength of 1 $within"
        );
        Assert::maxLength(
            $this->note,
            2000,
            "note in RequestDenyOffer must have maxlength of 2000 $within"
        );
    }

    private function map(array $data)
    {
        if (isset($data['note'])) {
            $this->note = $data['note'];
        }
    }

    public function __construct(array $data = null)
    {
        if (isset($data)) {
            $this->map($data);
        }
    }
}
